AHSAH is a small hashing crate with incremental digest contexts, reader helpers, and compatibility shims for the older builder API.
Re-exports
pub use algorithms::Md5;pub use algorithms::Sha224;pub use algorithms::Sha256;pub use algorithms::Sha384;pub use algorithms::Sha512;pub use algorithms::MD5;pub use digest::Digest;pub use encoding::DigestBytes;pub use hasher::Generic;pub use hasher::HashBuilder;pub use hasher::Hasher;pub use hasher::WithReader;pub use hasher::WithoutReader;pub use io::digest_reader;pub use io::update_reader;